# Euler v2 (EVK / eVault) Adapter

- **Module**: `wayfinder_paths.adapters.euler_v2_adapter.adapter.EulerV2Adapter`
- **Protocol**: Euler v2 (Euler Vault Kit / eVaults)

## Notes

- Markets are **vaults** (the vault address is also the ERC-4626 share token).
- The adapter uses **EVC (Ethereum Vault Connector)** batching for vault operations.

